@@ -27,6 +27,7 @@ from Xlib import X
 from Xlib import XK
 from Xlib.ext import record
 from Xlib.protocol import rq
+import locale
 import sys
 import time
 import threading
@@ -67,9 +68,9 @@ class XEvent(object):
 class XEvents(threading.Thread):
   """A thread to queue up X window events from RECORD extension."""
 
-  _butn_to_code = collections.defaultdict(lambda: 'BTN_DUNNO',
-      [(1, 'BTN_LEFT'), (2, 'BTN_MIDDLE'), (3, 'BTN_RIGHT'),
-       (4, 'REL_WHEEL'), (5, 'REL_WHEEL'), (6, 'REL_LEFT'), (7, 'REL_RIGHT')])
+  _butn_to_code = {
+      1: 'BTN_LEFT', 2: 'BTN_MIDDLE', 3: 'BTN_RIGHT',
+      4: 'REL_WHEEL', 5: 'REL_WHEEL', 6: 'REL_LEFT', 7: 'REL_RIGHT'}
 
   def __init__(self):
     threading.Thread.__init__(self)
@@ -89,10 +90,16 @@ class XEvents(threading.Thread):
 
   def _setup_lookup(self):
     """Setup the key lookups."""
+    # set locale to default C locale, see Issue 77.
+    # Use setlocale(None) to get curent locale instead of getlocal.
+    # See Issue 125 and http://bugs.python.org/issue1699853.
+    OLD_CTYPE = locale.setlocale(locale.LC_CTYPE, None)
+    locale.setlocale(locale.LC_CTYPE, 'C')
     for name in dir(XK):
       if name[:3] == "XK_":
         code = getattr(XK, name)
-        self.keycode_to_symbol[code] = 'KEY_' + str(unicode(name[3:]).upper())
+        self.keycode_to_symbol[code] = 'KEY_' + name[3:].upper()
+    locale.setlocale(locale.LC_CTYPE, OLD_CTYPE)
     self.keycode_to_symbol[65027] = 'KEY_ISO_LEVEL3_SHIFT'
     self.keycode_to_symbol[269025062] = 'KEY_BACK'
     self.keycode_to_symbol[269025063] = 'KEY_FORWARD'
@@ -197,10 +204,10 @@ class XEvents(threading.Thread):
       else:
         value = 1
       self.events.append(XEvent('EV_REL',
-          0, XEvents._butn_to_code[event.detail], value))
+          0, XEvents._butn_to_code.get(event.detail, 'BTN_%d' % event.detail), value))
     else:
       self.events.append(XEvent('EV_KEY',
-          0, XEvents._butn_to_code[event.detail], value))
+          0, XEvents._butn_to_code.get(event.detail, 'BTN_%d' % event.detail), value))
 
   def _handle_key(self, event, value):
     """Add key event to events.
